@@ -11,8 +11,18 @@ class Akses:
     kemudahan: YaTidak = YaTidak.YA
 
     def __attrs_post_init__(self):
-        waktu = int(self.waktu) / 60
-        self.waktu = str(waktu)
+        if self.jarak in (None, "None"):
+            self.jarak = "0"
+        if self.waktu in (None, "None"):
+            self.waktu = "0"
+        elif self.waktu == "0":
+            pass
+        elif self.waktu.isdigit():
+            waktu = int(self.waktu) / 60
+            self.waktu = str(round(waktu, 4))
+        elif self.waktu.isdecimal():
+            waktu = float(self.waktu) / 60
+            self.waktu = str(round(waktu, 4))
 
     @staticmethod
     def from_cols(ws: Worksheet, row: int, j: str, w: str, k: str):
