@@ -1,4 +1,5 @@
 import cattr
+import click
 from datetime import date, datetime
 from dateutil import parser
 from enum import Enum
@@ -34,15 +35,32 @@ def register_cattr_hooks():
 E = TypeVar("E", bound=Enum)
 
 
+def isequal(a: Any, b: str) -> bool:
+    if a is None:
+        return False
+    elif isinstance(a, str) and a.strip().lower() == b.lower():
+        return True
+    return a == b
+
+
 def make_str_to_enum(mapping: Dict[str, Any], default_value: Union[str, int] = "1"):
     def str_to_enum(cls: Type[E], val: Union[str, int], t: Type[E] = None) -> E:
-        if isinstance(val, int):
-            if str(val) in cls:
-                return cls(str(val))
+        if val is None:
+            click.echo(f"Kolom kosong, akan diisi {cls(default_value)}")
             return cls(default_value)
+        elif isinstance(val, int):
+            try:
+                return cls(val)
+            except ValueError:
+                return cls(str(val))
+        elif val.isdigit():
+            return cls(val)
         for key, enum_val in mapping.items():
-            if key.lower() == val.lower():
+            if isequal(val, key):
                 return cls(enum_val)
+        click.echo(
+            f"Isian tidak cocok dengan Referensi : {val}! Akan diisi {cls(default_value)}!"
+        )
         return cls(default_value)
 
     return str_to_enum
